import { useColorModeValue } from '@chakra-ui/color-mode';
import { Spinner } from '@chakra-ui/spinner';
import { useStyles, useTheme, chakra, forwardRef, useMultiStyleConfig, omitThemingProps, StylesProvider } from '@chakra-ui/system';
import { getColor, mode, darken, lighten } from '@chakra-ui/theme-tools';
import { Collapse } from '@chakra-ui/transition';
import { motion, AnimatePresence } from 'framer-motion';
import { memo, createElement, useMemo, Fragment, Children, isValidElement, cloneElement, useState } from 'react';
import { createIcon } from '@chakra-ui/icon';
import { useMediaQuery } from '@chakra-ui/react';
import { cx } from '@chakra-ui/utils';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MotionDiv = /*#__PURE__*/motion(chakra.div);
var Connector = /*#__PURE__*/memo(function (_ref) {
  var c = _ref.colorScheme,
      isCompletedStep = _ref.isCompletedStep,
      isVertical = _ref.isVertical,
      children = _ref.children,
      isLastStep = _ref.isLastStep,
      hasLabel = _ref.hasLabel;

  var _useStyles = useStyles(),
      connector = _useStyles.connector,
      stepIcon = _useStyles.stepIcon;

  var theme = useTheme();
  var activeBg = useColorModeValue(c + ".500", c + ".200");
  var inactiveBg = useColorModeValue("gray.200", "gray.700");
  var rawInitialColor = getColor(theme, inactiveBg);
  var rawActiveColor = getColor(theme, activeBg);

  var getMargin = function getMargin() {
    if (isVertical) return "calc(" + stepIcon.width + " / 2)";
    if (!hasLabel) return 2;
    return 0;
  };

  return createElement(MotionDiv, {
    __css: _extends({}, connector, {
      ml: getMargin(),
      my: isVertical ? 2 : 0,
      pl: isVertical ? 4 : 0,
      borderTopWidth: isLastStep || isVertical ? 0 : '2px',
      borderLeftWidth: isLastStep || !isVertical ? 0 : '2px',
      minHeight: isLastStep || !isVertical ? 'auto' : '1.5rem'
    }),
    initial: {
      borderColor: rawInitialColor
    },
    animate: {
      borderColor: isCompletedStep ? rawActiveColor : rawInitialColor
    }
  }, isVertical && children);
});

var CheckIcon = /*#__PURE__*/createIcon({
  viewBox: '0 0 14 14',
  path: /*#__PURE__*/createElement("g", {
    fill: "currentColor"
  }, /*#__PURE__*/createElement("polygon", {
    points: "5.5 11.9993304 14 3.49933039 12.5 2 5.5 8.99933039 1.5 4.9968652 0 6.49933039"
  }))
});

var CloseIcon = /*#__PURE__*/createIcon({
  displayName: 'CloseIcon',
  d: 'M.439,21.44a1.5,1.5,0,0,0,2.122,2.121L11.823,14.3a.25.25,0,0,1,.354,0l9.262,9.263a1.5,1.5,0,1,0,2.122-2.121L14.3,12.177a.25.25,0,0,1,0-.354l9.263-9.262A1.5,1.5,0,0,0,21.439.44L12.177,9.7a.25.25,0,0,1-.354,0L2.561.44A1.5,1.5,0,0,0,.439,2.561L9.7,11.823a.25.25,0,0,1,0,.354Z'
});

var _excluded = ["children", "isCompletedStep", "isCurrentStep", "index", "colorScheme", "label", "isLastStep", "icon", "orientation", "description", "state"];
var AnimatedCheck = /*#__PURE__*/motion(CheckIcon);
var AnimatedCloseIcon = /*#__PURE__*/motion(CloseIcon);
var AnimatedSpan = /*#__PURE__*/motion(chakra.span);
var animationConfig = {
  transition: {
    duration: 0.15
  },
  exit: {
    scale: 0,
    opacity: 0
  },
  initial: {
    scale: 0,
    opacity: 0
  },
  animate: {
    scale: 1,
    opacity: 1
  }
};
var Step = /*#__PURE__*/forwardRef(function (props, ref) {
  var children = props.children,
      isCompletedStep = props.isCompletedStep,
      isCurrentStep = props.isCurrentStep,
      index = props.index,
      c = props.colorScheme,
      labelProp = props.label,
      isLastStep = props.isLastStep,
      CustomIcon = props.icon,
      orientation = props.orientation,
      descriptionProp = props.description,
      state = props.state,
      styleProps = _objectWithoutPropertiesLoose(props, _excluded);

  var Icon = useMemo(function () {
    return CustomIcon ? motion(CustomIcon) : null;
  }, [CustomIcon]);

  var _useStyles = useStyles(),
      step = _useStyles.step,
      stepIcon = _useStyles.stepIcon,
      label = _useStyles.label,
      description = _useStyles.description,
      icon = _useStyles.icon;

  var activeBg = c + ".500";
  var inactiveBg = useColorModeValue("gray.200", "gray.700");
  var isError = state === 'error';
  var isLoading = state === 'loading';
  var getBorderColor = useMemo(function () {
    if (isCompletedStep) return activeBg;

    if (isCurrentStep) {
      if (isError) {
        return 'red.500';
      }

      return activeBg;
    }

    return inactiveBg;
  }, [isError, isCompletedStep, isCurrentStep, activeBg, inactiveBg]);
  var getBgColor = useMemo(function () {
    if (isCompletedStep) return activeBg;

    if (isCurrentStep) {
      if (isError) {
        return 'red.500';
      }

      return mode(darken(inactiveBg, 0.5), lighten(inactiveBg, 0.5));
    }

    return inactiveBg;
  }, [isError, isCompletedStep, isCurrentStep, activeBg, inactiveBg]);
  var hasVisited = isCurrentStep || isCompletedStep;
  var opacity = hasVisited ? 1 : 0.8;
  var isVertical = orientation === 'vertical';

  var renderIcon = function renderIcon() {
    if (isCompletedStep) {
      return createElement(AnimatedCheck, Object.assign({
        key: "icon",
        color: "white"
      }, animationConfig, icon));
    }

    if (isCurrentStep) {
      if (isError) return createElement(AnimatedCloseIcon, Object.assign({
        key: "icon",
        color: "white"
      }, animationConfig, icon));
      if (isLoading) return createElement(Spinner, {
        width: icon.width,
        height: icon.height
      });
    }

    if (Icon) return createElement(Icon, null);
    return createElement(AnimatedSpan, Object.assign({
      key: "label",
      __css: label
    }, animationConfig), (index || 0) + 1);
  };

  return createElement(Fragment, null, createElement(chakra.div, Object.assign({
    ref: ref
  }, styleProps, {
    "aria-disabled": !hasVisited,
    __css: _extends({}, step, {
      opacity: opacity,
      flexDir: isVertical ? 'column' : 'row',
      alignItems: isVertical ? 'flex-start' : 'center',
      flex: isLastStep && !isVertical ? '0 0 auto' : '1 0 auto',
      justifyContent: isLastStep && !isVertical ? 'flex-end' : 'flex-start'
    })
  }), createElement(chakra.div, {
    __css: {
      display: 'flex',
      flexDir: 'row',
      alignItems: 'center'
    }
  }, createElement(chakra.div, {
    __css: _extends({}, stepIcon, {
      bg: getBgColor,
      borderColor: getBorderColor
    })
  }, createElement(AnimatePresence, {
    exitBeforeEnter: true
  }, renderIcon())), createElement(chakra.div, {
    "aria-current": isCurrentStep,
    __css: {
      display: 'flex',
      flexDir: 'column',
      justifyContent: 'center',
      alignItems: 'flex-start'
    }
  }, !!labelProp && createElement(chakra.span, {
    __css: _extends({
      mx: 2,
      opacity: opacity
    }, label)
  }, labelProp), !!descriptionProp && createElement(chakra.span, {
    __css: _extends({
      mx: 2,
      opacity: opacity
    }, description)
  }, descriptionProp))), createElement(Connector, {
    colorScheme: c,
    isLastStep: isLastStep,
    isVertical: isVertical,
    isCompletedStep: isCompletedStep || false,
    hasLabel: !!labelProp || !!descriptionProp
  }, createElement(Collapse, {
    style: {
      width: '100%'
    },
    "in": isCurrentStep
  }, children))));
});

var _excluded$1 = ["className", "activeStep", "children", "orientation", "state", "responsive"];
var Steps = /*#__PURE__*/forwardRef(function (props, ref) {
  var styles = useMultiStyleConfig('Steps', props);

  var _omitThemingProps = omitThemingProps(props),
      className = _omitThemingProps.className,
      activeStep = _omitThemingProps.activeStep,
      children = _omitThemingProps.children,
      orientationProp = _omitThemingProps.orientation,
      state = _omitThemingProps.state,
      responsive = _omitThemingProps.responsive,
      rest = _objectWithoutPropertiesLoose(_omitThemingProps, _excluded$1);

  var childArr = Children.toArray(children);
  var stepCount = childArr.length;

  var renderHorizontalContent = function renderHorizontalContent() {
    if (activeStep <= childArr.length) {
      return Children.map(childArr[activeStep], function (node) {
        if (!isValidElement(node)) return;
        return Children.map(node.props.children, function (childNode) {
          return childNode;
        });
      });
    }

    return null;
  };

  var _useMediaQuery = useMediaQuery('(max-width: 43em)'),
      isMobile = _useMediaQuery[0];

  var orientation = isMobile && responsive ? 'vertical' : orientationProp;
  return createElement(StylesProvider, {
    value: styles
  }, createElement(chakra.div, Object.assign({
    ref: ref,
    __css: _extends({
      justifyContent: stepCount === 1 ? 'flex-end' : 'space-between',
      flexDir: orientation === 'vertical' ? 'column' : 'row'
    }, styles.steps)
  }, rest, {
    className: cx('chakra-steps', className)
  }), Children.map(children, function (child, i) {
    var _ref;

    var isCompletedStep = (_ref = isValidElement(child) && child.props.isCompletedStep) != null ? _ref : i < activeStep;
    var isLastStep = i === stepCount - 1;
    var isCurrentStep = i === activeStep;
    var stepProps = {
      index: i,
      colorScheme: props.colorScheme,
      isCompletedStep: isCompletedStep,
      isCurrentStep: isCurrentStep,
      isLastStep: isLastStep,
      orientation: orientation,
      state: state
    };
    return isValidElement(child) ? cloneElement(child, stepProps) : null;
  })), orientation === 'horizontal' && renderHorizontalContent());
});
Steps.defaultProps = {
  activeStep: 0,
  colorScheme: 'green',
  orientation: 'horizontal',
  responsive: true
};

function useSteps(_ref) {
  var initialStep = _ref.initialStep;

  var _React$useState = useState(initialStep),
      activeStep = _React$useState[0],
      setActiveStep = _React$useState[1];

  var nextStep = function nextStep() {
    setActiveStep(function (prev) {
      return prev + 1;
    });
  };

  var prevStep = function prevStep() {
    setActiveStep(function (prev) {
      return prev - 1;
    });
  };

  var reset = function reset() {
    setActiveStep(initialStep);
  };

  return {
    nextStep: nextStep,
    prevStep: prevStep,
    reset: reset,
    activeStep: activeStep
  };
}

var parts = ['steps', 'step', 'stepIcon', 'connector', 'label', 'description'];

var baseStyle = function baseStyle(props) {
  return {
    steps: {
      fontFamily: 'heading',
      textAlign: 'center',
      width: '100%',
      display: 'flex',
      flex: 1
    },
    step: {
      display: 'flex',
      position: 'relative',
      alignItems: 'center',
      justifyContent: 'flex-start'
    },
    stepIcon: {
      display: 'flex',
      borderRadius: '50%',
      alignItems: 'center',
      justifyContent: 'center'
    },
    connector: {
      flex: 1,
      display: 'flex',
      height: '2px',
      mr: 2
    },
    label: {
      fontWeight: 'medium',
      color: mode("gray.900", "gray.100")(props),
      textAlign: 'center',
      fontSize: 'md'
    },
    description: {
      marginTop: '-2px',
      color: mode("gray.800", "gray.200")(props),
      textAlign: 'center',
      opacity: 0.9,
      fontSize: 'sm'
    }
  };
};

var sizes = {
  sm: {
    stepIcon: {
      width: '32px',
      height: '32px',
      borderWidth: '2px'
    },
    icon: {
      width: '16px',
      height: '16px'
    },
    label: {
      fontWeight: 'medium',
      textAlign: 'center',
      fontSize: 'sm'
    },
    description: {
      fontWeight: '300',
      textAlign: 'center',
      fontSize: 'xs'
    }
  },
  md: {
    stepIcon: {
      width: '40px',
      height: '40px',
      borderWidth: '2px'
    },
    icon: {
      width: '20px',
      height: '20px'
    },
    label: {
      fontWeight: 'medium',
      textAlign: 'center',
      fontSize: 'md'
    },
    description: {
      fontWeight: '300',
      textAlign: 'center',
      fontSize: 'sm'
    }
  },
  lg: {
    stepIcon: {
      width: '48px',
      height: '48px',
      borderWidth: '2px'
    },
    icon: {
      width: '24px',
      height: '24px'
    },
    label: {
      fontWeight: 'bold',
      textAlign: 'center',
      fontSize: 'lg'
    },
    description: {
      fontWeight: '300',
      textAlign: 'center',
      fontSize: 'md'
    }
  }
};
var defaultProps = {
  size: 'md',
  colorScheme: 'green'
};
var StepsStyleConfig = {
  parts: parts,
  baseStyle: baseStyle,
  sizes: sizes,
  defaultProps: defaultProps
};

export { Step, Steps, StepsStyleConfig, useSteps };
//# sourceMappingURL=chakra-ui-steps.esm.js.map
